import fs from 'fs';
import { v4 as uuid } from 'uuid';
import path from 'path';
import minioConfig from "../config/minioConfig.js"
import { sendError, sendResponse } from '../utils/mensagens.js';


export default class UploadImagemController {

    static async upload(req, res) {
        try {
            const file = req.file;

            const extencaoDoArquivo = path.extname(file.originalname);
            const novoNomeArquivo = uuid();
            const objectName = `${novoNomeArquivo}${extencaoDoArquivo}`;

            await minioConfig.fPutObject("imagens", objectName, file.path);

            fs.unlinkSync(file.path);

            return sendResponse(res, 201, { data: [{file: objectName}] })
        } catch (err) {
            sendError(res, 500, err.message)
        }
    }

    static async buscarImagem(req, res) {
        try {
            const objectName = req.params.nome;

            const stream = await minioConfig.getObject('imagens', objectName);

            stream.on('data', (chunk) => {
                res.write(chunk);
            })

            stream.on('end', () => {
                res.end();
            })

            stream.on('error', (err) => {
                return sendError(res, 500, err.message)
            })

        } catch (err) {
            return sendError(res, 500, err.message)
        }
    }

    static async deleteImage(req, res) {
        try {
            const objectName = req.params.nome
            const bucketName = 'imagens'

            const objectsStream = minioConfig.listObjectsV2(bucketName, objectName, true);

            let objectExists = false;
            for await (const obj of objectsStream) {
                if (obj.name === objectName) {
                    objectExists = true;
                    break;
                }
            }

            if (!objectExists) {
                return sendError(res, 404, 'Imagem não encontrada!')
            }

            await minioConfig.removeObject(bucketName, objectName)

            return sendResponse(res, 201, [])
        } catch (err) {
            return sendError(res, 500, err.message)
        }
    }
}