import loginPaths from "../paths/loginPaths.js";
import recuperarSenhaPaths from "../paths/recuperarSenhaPaths.js";
import { itensPaths } from "../paths/itensPath.js";
import { itensSchemas } from "../schemas/itensSchema.js";
import { campusSchema } from "../schemas/campusSchema.js";
import { campusPaths } from "../paths/campusPaths.js";
import { setorSchema } from "../schemas/setorSchema.js";
import { setorPaths } from "../paths/setorPaths.js";
import { usuarioSchema } from "../schemas/usuarioSchema.js";
import { usuarioPaths } from "../paths/usuarioPaths.js";
import { inventarioSchema } from "../schemas/inventarioSchema.js";
import { inventarioPaths } from "../paths/inventarioPaths.js";
import relatorioPath from "../paths/relatorioPath.js";
import { UploadImagemPaths } from "../paths/UploadImagemPaths.js";
import { ItemSemEtiquetaSchemas } from "../schemas/itensSemEtiquetas.js";
import { UploadImagemSchema } from "../schemas/UploadImagemSchema.js";

const swaggerOptions = {
  swaggerDefinition: {
    openapi: "3.0.0",
    info: {
      title: "API- Levantamento Patrimonial",
      description:
        "O projeto foi desenvolvido para a Fabrica de Softwre(FSLab) do curso de Análise e Desenvolvimento de Sistemas do Instituto Federal de Rondônia - IFRO.",
      version: "0.0.1",
      license: {
        name: "GPLv3",
        url: "http://www.gnu.org/licenses/gpl-3.0.html",
      },
    },
    externalDocs: {
      description: "Documentação detalhada",
      url: "",
    },
    servers: [
      
      {
        url: `https://api-levantamento.app.fslab.dev`,
        description: "API em produção",
      },
      {
        url: `http://localhost:${process.env.PORT}`,
        description: "API em desenvolvimento",
      },
    ],
    components: {
      securitySchemes: {
        jwtAuth: {
          type: 'http',
          scheme: 'bearer',
          bearerFormat: 'JWT',
        },
      },
      schemas: {
        ...itensSchemas,
        ...inventarioSchema,
        ...campusSchema,
        ...setorSchema,
        ...usuarioSchema,
        ...ItemSemEtiquetaSchemas,
        ...UploadImagemSchema
      },
    },
    security: [
      {
        jwtAuth: [],
      },
    ],
    tags: [
      {
        name: "Login",
        description: "Login do usuário",
      },
      {
        name: "Recuperar senha",
        description: "Recuperação de senha",
      },
      {
        name: "Imagens",
        description: "Upload de imagens",
      },
      {
        name: "Campus",
        description: "Campus do IFRO",
      },
      {
        name: "Relatórios",
        description: "Relatórios do sistema",
      },
      {
        name: "Usuários",
        description: "Usuários do sistema",
      },
      {
        name: "Itens",
        description: "Itens do inventário",
      },
      { 
        name: "Inventários",
        description: "Invetários do campus"
      },
      {
        name: "Setores",
        description: "Setores do inventário",
      },

      {
        name: "Campus",
        description: "Campus do usuário"
      },
    ],
    paths: {
      ...loginPaths,
      ...usuarioPaths,
      ...recuperarSenhaPaths,
      ...itensPaths,
      ...inventarioPaths,
      ...setorPaths,
      ...campusPaths,
      ...relatorioPath,
      ...UploadImagemPaths
    },
  },
  apis: ["./src/routes/*.js"],
};

export default swaggerOptions;