import { gerarRespostasCorretas, gerarRespostasDeErro } from "../communs.js";

export const UploadImagemPaths = {
    "/imagens/upload": {
        post: {
            tags: ["Imagens"],
            security: [
                {
                    jwtAuth: []
                }
            ],
            summary: "Upload de Imagem",
            description: "Faz o upload de uma imagem para o servidor e armazena no MinIO. A imagem deve ser enviada no corpo da requisição como um arquivo do tipo multipart/form-data.",
            requestBody: {
                content: {
                    "multipart/form-data": {
                        schema: {
                            type: "object",
                            properties: {
                                file: {
                                    type: "string",
                                    format: "binary",
                                    description: "Imagem a ser enviada para o upload.",
                                }
                            },
                            required: ["file"]
                        }
                    }
                }
            },
            responses: {
                ...gerarRespostasCorretas(201, "#/components/schemas/UploadImagemResponse"),
                ...gerarRespostasDeErro([401, 403, 422, 498, 500])
            }
        }
    },
    "/imagens/{nome}": {
        get: {
            tags: ["Imagens"],
            // security: [{ jwtAuth: [] }],
            summary: "Obter Imagem",
            description: "Recupera uma imagem específica identificada pelo nome fornecido. A imagem é retornada no formato binário para ser exibida ou baixada pelo usuário.",
            parameters: [
                {
                    name: "nome",
                    in: "path",
                    description: "Nome da imagem a ser obtida",
                    required: true,
                    schema: {
                        type: "string"
                    }
                }
            ],
            responses: {
                200: {
                    description: "Imagem recuperada com sucesso",
                    content: {
                        "image/jpg": {
                            schema: {
                                type: "string",
                                format: "binary",
                            },
                        },
                    },
                },
            }
        },
        delete: {
            tags: ["Imagens"],
            summary: "Excluir Imagem",
            description: "Exclui uma imagem específica identificada pelo nome fornecido. A operação não retorna conteúdo, mas o código de status 204 indica que a imagem foi excluída com sucesso.",
            parameters: [
                {
                    name: "nome",
                    in: "path",
                    description: "Nome da imagem a ser excluída",
                    required: true,
                    schema: {
                        type: "string"
                    }
                }
            ],
            responses: {
                ...gerarRespostasCorretas(201, "#/components/schemas/ImagemResponse"),
                ...gerarRespostasDeErro([401, 403, 422, 498, 500])
            }
        }
    }
}
