export const ItemSemEtiquetaSchemas = {
    ItemSemEtiqueta: {
        type: "object",
        properties: {
            nao_etiquetado: {
                type: "boolean",
                description: "Indica se o item não está etiquetado",
                example: true
            },
            estado: {
                type: "string",
                description: "Estado do item (Bem danificado, Bem em condições de uso, Bem inservível)",
                enum: ["Bem danificado", "Bem em condições de uso", "Bem inservível"],
                default: "Bem em condições de uso",
                example: "Bem em condições de uso"
            },
            ativo: {
                type: "string",
                description: "Status do item (Ativo, Inativo, Pendente)",
                enum: ["Ativo", "Inativo", "Pendente"],
                default: "Ativo",
                example: "Ativo"
            },
            ocioso: {
                type: "boolean",
                description: "Indica se o item está ocioso (não está sendo usado)",
                example: false
            },
            descricao: {
                type: "string",
                description: "Observações adicionais sobre o item",
                maxLength: 256,
                example: "Observação sobre o estado do item"
            },
            inventario: {
                type: "string",
                format: "uuid",
                description: "ID do inventário ao qual o item pertence",
                example: "123e4567-e89b-12d3-a456-426614174000"
            },
            setor: {
                type: "string",
                format: "uuid",
                description: "ID do setor onde o item está localizado",
                example: "123e4567-e89b-12d3-a456-426614174000"
            },
            auditor: {
                type: "string",
                format: "uuid",
                description: "ID do usuário que auditou o item",
                example: "123e4567-e89b-12d3-a456-426614174000"
            },
            imagem: {
                type: "string",
                description: "Nome da imagem do item",
                example: "imagem.jpg"
            },
            createdAt: {
                type: "string",
                format: "date-time",
                description: "Data e hora em que o item foi criado",
                example: "2024-09-07T12:34:56Z"
            },
            updatedAt: {
                type: "string",
                format: "date-time",
                description: "Data e hora da última atualização do item",
                example: "2024-09-07T12:34:56Z"
            }
        },
        required: ["inventario", "setor", "auditor"],
        description: "Representação de um item sem etiqueta"
    },
    ItemSemEtiquetaRequestBody: {
        type: "object",
        properties: {
            estado: {
                type: "string",
                description: "Estado do item (Bem danificado, Bem em condições de uso, Bem inservível)",
                enum: ["Bem danificado", "Bem em condições de uso", "Bem inservível"],
                example: "Bem em condições de uso"
            },
            ocioso: {
                type: "boolean",
                description: "Indica se o item está ocioso (não está sendo usado)",
                example: false
            },
            descricao: {
                type: "string",
                description: "Observações adicionais sobre o item",
                maxLength: 256,
                example: "Observação sobre o estado do item"
            },
            setor: {
                type: "string",
                format: "uuid",
                description: "ID do setor onde o item está localizado",
                example: "123e4567-e89b-12d3-a456-426614174000"
            },
            imagem: {
                type: "string",
                description: "Nome da imagem do item",
                example: "imagem.jpg"
            }
        },
        required: ["descricao", "setor", "imagem"],
        description: "Corpo da requisição para criar ou atualizar um item sem etiqueta"
    }
};
