import messages, { sendError } from "../../utils/mensagens.js";
import minioConfig from "../../config/minioConfig.js"

import { Validator, ValidationFuncs as v } from "./validation.js";

class ValidateUploadImagem {

    static async validateCriar(req, res, next) {

        // Validação para verificar se o arquivo é uma imagem
        const validImageTypes = [
            'image/jpeg', 'image/jpg', 'image/png', 'image/gif', 'image/webp',
            'image/bmp', 'image/tiff', 'image/svg+xml', 'image/x-icon', 'image/heic',
            'image/heif', 'image/avif', 'image/x-png', 'image/x-citrix-png', 'image/x-citrix-jpeg',
            'image/vnd.microsoft.icon', 'image/vnd.wap.wbmp', 'image/x-ms-bmp'
        ];

        const val = new Validator({ ...req.file, file: req.file });

        await val.validate("file", v.required());

        if (val.anyErrors()) return sendError(res, 422, val.getErrors());

        await val.validate("mimetype", v.required(), v.enum({
            values: validImageTypes, message: "O arquivo enviado não é uma imagem válida!"
        }));

        if (val.anyErrors()) return sendError(res, 422, val.getErrors());
        req.body = val.getSanitizedBody();

        const bucketExists = await minioConfig.bucketExists("imagens");
        if (!bucketExists) {
            await minioConfig.makeBucket("imagens", 'us-east-1');
        }

        return next();
    }
}

export default ValidateUploadImagem;