import mongoose from "mongoose";
import paginate from "mongoose-paginate-v2";

export const ESTADO_ITEM = {
    DANIFICADO: "Bem danificado",
    CONDICAO_USO: "Bem em condições de uso",
    INSERSIVEL:  "Bem inservivel"
};

export const ATIVO_ITEM = {
    ATIVO: "Ativo",
    INATIVO: "Inativo",
    PENDENTE: "Pendente"
};

const itemSemEtiquetaSchema = new mongoose.Schema({
    nao_etiquetado: {
        type: Boolean,
        default: true
    },
    estado: {
        type: String, // Bem danificado, Bem em condições de uso, Bem inservivel
        enum: Object.values(ESTADO_ITEM),
        default: ESTADO_ITEM.CONDICAO_USO
    },
    ativo: {
        type: String,
        enum: Object.values(ATIVO_ITEM),
        default: ATIVO_ITEM.ATIVO  // Ativo, Inativo, Pendente
    },
    ocioso: {
        type: Boolean, // Não está sendo usado
        default: false
    },
    descricao: {
        type: String, // Alterar para ter um maximo de texto
        maxlength: 256,
    },
    inventario: {
        type: mongoose.Schema.Types.ObjectId,
        ref: "inventarios", // Ja tem que puxar automatico
        required: true
    },
    setor: {
        type: mongoose.Schema.Types.ObjectId,
        ref: "setores",
        required: true
    },
    auditor: {
        type: mongoose.Schema.Types.ObjectId,
        ref: "usuarios",
        required: true
    }, 
    imagem: {
        type: String
    }
},
    { timestamps: { createdAt: "createdAt", updatedAt: "updatedAt" } }
);

// Configurações do modelo para que seja usada para buscar dados de usuário de forma paginada em nossa aplicação
itemSemEtiquetaSchema.plugin(paginate);

const itemSemEtiqueta = mongoose.model("itensSemEtiqueta", itemSemEtiquetaSchema);

export default itemSemEtiqueta;