import express from "express";
import ItemController from "../controllers/ItemController.js";
import ValidateItem from "../middlewares/validation/itemValidation.js";
import { AuthMiddleware } from "../middlewares/AuthMiddleware.js";
import { verificarPermissao } from "../middlewares/PermissaoMiddleware.js";
import { ACAO, PERM } from "../models/Grupo.js";

const router = express.Router();

router.get("/itens", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.VER),
    ItemController.pesquisarItem
);

router.get("/itens/ultimo_inventario", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.VER),
    ItemController.listarUltimosItens
);

router.get("/itens/inventario_atual", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.VER),
    ItemController.listarItensInventarioAtual);


router.get("/itens/:id", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.VER),
    ItemController.listarItemID
);

router.patch("/itens/:id", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.EDITAR),
    ValidateItem.validateAlterar, ItemController.atualizarItem
);

router.post("/itens", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.CRIAR),
    ValidateItem.validateCriar, ItemController.criarItem
);

router.delete("/itens/:id", AuthMiddleware,
    verificarPermissao(PERM.ITEM, ACAO.DELETAR),
    ItemController.deletarItem
);

router.post("/itens/sem_etiqueta", AuthMiddleware,
    ValidateItem.validateCriarItemSemEtiqueta,
    ItemController.criarItemSemEtiqueta
);

export default router;